slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSBLOPEXGetBlockSize

Gets the block size used in the BLOPEX solver.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSBLOPEXGetBlockSize(EPS eps,PetscInt *bs)

Not Collective

### Input Parameter

| eps | - the eigenproblem solver context

### Output Parameter

| bs | - the block size

### See Also

EPSBLOPEXSetBlockSize()

### Level

advanced

### Location

src/eps/impls/external/blopex/blopex.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages